package
Version:
v0.0.0-...-e7af3d8
Opens a new window with list of versions in this module.
Published: Sep 11, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Simple Package for basic math opertaions
func Add(numbers ...interface{}) float64
Add Any number of integers
func Divide(numbers ...interface{}) float64
Divide Any number of integers
func Multiply(numbers ...interface{}) float64
Multiply Any number of integers
func Subtract(numbers ...interface{}) float64
Subtract Any number of integers
Source Files
¶
Click to show internal directories.
Click to hide internal directories.